summaryrefslogtreecommitdiffstats
path: root/lib/widgets
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-02-01 15:15:35 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-02-01 15:15:35 -0600
commitf78eb03afb8c9a380985d26286afc40b4c89b292 (patch)
tree3c087e2f119e645c902958c3bc3c802abf078ad0 /lib/widgets
parentda1941ccadffe5ae70ee111c53f0ec2b3d990869 (diff)
downloadtdevelop-f78eb03afb8c9a380985d26286afc40b4c89b292.tar.gz
tdevelop-f78eb03afb8c9a380985d26286afc40b4c89b292.zip
Rename a number of classes to enhance compatibility with KDE4
Diffstat (limited to 'lib/widgets')
-rw-r--r--lib/widgets/fancylistviewitem.cpp2
-rw-r--r--lib/widgets/fancylistviewitem.h8
-rw-r--r--lib/widgets/kcomboview.cpp2
-rw-r--r--lib/widgets/kdevhtmlpart.cpp26
-rw-r--r--lib/widgets/kdevhtmlpart.h18
-rw-r--r--lib/widgets/klistviewaction.cpp22
-rw-r--r--lib/widgets/klistviewaction.h8
-rw-r--r--lib/widgets/ksavealldialog.cpp4
-rw-r--r--lib/widgets/ksavealldialog.h4
-rw-r--r--lib/widgets/processwidget.cpp2
-rw-r--r--lib/widgets/processwidget.h2
-rw-r--r--lib/widgets/propeditor/pfontbutton.cpp2
-rw-r--r--lib/widgets/propeditor/pfontbutton.h4
-rw-r--r--lib/widgets/propeditor/pfontcombo.cpp4
-rw-r--r--lib/widgets/propeditor/pfontcombo.h6
-rw-r--r--lib/widgets/propeditor/propertyeditor.cpp34
-rw-r--r--lib/widgets/propeditor/propertyeditor.h6
17 files changed, 77 insertions, 77 deletions
diff --git a/lib/widgets/fancylistviewitem.cpp b/lib/widgets/fancylistviewitem.cpp
index 6956636e..f3e686c9 100644
--- a/lib/widgets/fancylistviewitem.cpp
+++ b/lib/widgets/fancylistviewitem.cpp
@@ -58,7 +58,7 @@ TQString FancyListViewItem::text(int column) const {
TQColor FancyListViewItem::backgroundColor(int col) {
- return KListViewItem::backgroundColor(col);
+ return TDEListViewItem::backgroundColor(col);
}
diff --git a/lib/widgets/kcomboview.cpp b/lib/widgets/kcomboview.cpp
index 93a6612f..a18dc93c 100644
--- a/lib/widgets/kcomboview.cpp
+++ b/lib/widgets/kcomboview.cpp
@@ -86,7 +86,7 @@ void KComboView::setDefaultText( const TQString & text )
void KComboView::setUpListView()
{
- KListView *listView = new KListView( this, "in-combo" );
+ TDEListView *listView = new TDEListView( this, "in-combo" );
listView->setRootIsDecorated( false );
listView->setAllColumnsShowFocus(true);
listView->addColumn("");
diff --git a/lib/widgets/kdevhtmlpart.cpp b/lib/widgets/kdevhtmlpart.cpp
index 34d5a2c0..e92927ae 100644
--- a/lib/widgets/kdevhtmlpart.cpp
+++ b/lib/widgets/kdevhtmlpart.cpp
@@ -31,14 +31,14 @@ KDevHTMLPart::KDevHTMLPart()
connect(this, TQT_SIGNAL(completed()), this, TQT_SLOT(slotCompleted()));
connect(this, TQT_SIGNAL(canceled(const TQString &)), this, TQT_SLOT(slotCancelled(const TQString &)));
- KActionCollection * actions = actionCollection();// new KActionCollection( this );
- reloadAction = new KAction( i18n( "Reload" ), "reload", 0,
+ TDEActionCollection * actions = actionCollection();// new TDEActionCollection( this );
+ reloadAction = new TDEAction( i18n( "Reload" ), "reload", 0,
this, TQT_SLOT( slotReload() ), actions, "doc_reload" );
reloadAction->setWhatsThis(i18n("<b>Reload</b><p>Reloads the current document."));
- stopAction = new KAction( i18n( "Stop" ), "stop", 0,
+ stopAction = new TDEAction( i18n( "Stop" ), "stop", 0,
this, TQT_SLOT( slotStop() ), actions, "doc_stop" );
stopAction->setWhatsThis(i18n("<b>Stop</b><p>Stops the loading of current document."));
- duplicateAction = new KAction( i18n( "Duplicate Tab" ), "window_new", 0,
+ duplicateAction = new TDEAction( i18n( "Duplicate Tab" ), "window_new", 0,
this, TQT_SLOT( slotDuplicate() ), actions, "doc_dup" );
duplicateAction->setWhatsThis(i18n("<b>Duplicate window</b><p>Opens current document in a new window."));
printAction = KStdAction::print(this, TQT_SLOT(slotPrint()), actions, "print_doc");
@@ -49,7 +49,7 @@ KDevHTMLPart::KDevHTMLPart()
//BEGIN documentation history stuff
- m_backAction = new KToolBarPopupAction(i18n("Back"), "back", 0,
+ m_backAction = new TDEToolBarPopupAction(i18n("Back"), "back", 0,
this, TQT_SLOT(slotBack()),
actions, "browser_back");
m_backAction->setEnabled( false );
@@ -61,7 +61,7 @@ KDevHTMLPart::KDevHTMLPart()
connect(m_backAction->popupMenu(), TQT_SIGNAL(activated(int)),
this, TQT_SLOT(slotPopupActivated(int)));
- m_forwardAction = new KToolBarPopupAction(i18n("Forward"), "forward", 0,
+ m_forwardAction = new TDEToolBarPopupAction(i18n("Forward"), "forward", 0,
this, TQT_SLOT(slotForward()),
actions, "browser_forward");
m_forwardAction->setEnabled( false );
@@ -89,8 +89,8 @@ KDevHTMLPart::KDevHTMLPart()
void KDevHTMLPart::popup( const TQString & url, const TQPoint & p )
{
-// KPopupMenu popup( i18n( "Documentation Viewer" ), this->widget() );
- KPopupMenu popup(this->widget());
+// TDEPopupMenu popup( i18n( "Documentation Viewer" ), this->widget() );
+ TDEPopupMenu popup(this->widget());
bool needSep = false;
int idNewWindow = -2;
@@ -120,8 +120,8 @@ void KDevHTMLPart::popup( const TQString & url, const TQPoint & p )
printAction->plug(&popup);
popup.insertSeparator();
- KAction * incFontAction = this->action("incFontSizes");
- KAction * decFontAction = this->action("decFontSizes");
+ TDEAction * incFontAction = this->action("incFontSizes");
+ TDEAction * decFontAction = this->action("decFontSizes");
if ( incFontAction && decFontAction )
{
incFontAction->plug( &popup );
@@ -129,7 +129,7 @@ void KDevHTMLPart::popup( const TQString & url, const TQPoint & p )
popup.insertSeparator();
}
- KAction *ac = action("setEncoding");
+ TDEAction *ac = action("setEncoding");
if (ac)
ac->plug(&popup);
@@ -403,7 +403,7 @@ void KDevHTMLPart::slotForward()
void KDevHTMLPart::slotBackAboutToShow()
{
- KPopupMenu *popup = m_backAction->popupMenu();
+ TDEPopupMenu *popup = m_backAction->popupMenu();
popup->clear();
if ( m_Current == m_history.begin() ) return;
@@ -428,7 +428,7 @@ void KDevHTMLPart::slotBackAboutToShow()
void KDevHTMLPart::slotForwardAboutToShow()
{
- KPopupMenu *popup = m_forwardAction->popupMenu();
+ TDEPopupMenu *popup = m_forwardAction->popupMenu();
popup->clear();
if ( m_Current == m_history.fromLast() ) return;
diff --git a/lib/widgets/kdevhtmlpart.h b/lib/widgets/kdevhtmlpart.h
index 3dbc728e..6c8f7dc3 100644
--- a/lib/widgets/kdevhtmlpart.h
+++ b/lib/widgets/kdevhtmlpart.h
@@ -12,8 +12,8 @@
Customized TDEHTML part for KDevelop.
*/
-class KAction;
-class KToolBarPopupAction;
+class TDEAction;
+class TDEToolBarPopupAction;
struct DocumentationHistoryEntry {
KURL url;
@@ -93,17 +93,17 @@ private:
TQValueList< DocumentationHistoryEntry > m_history;
TQValueList< DocumentationHistoryEntry >::Iterator m_Current;
- KToolBarPopupAction* m_backAction;
- KToolBarPopupAction* m_forwardAction;
+ TDEToolBarPopupAction* m_backAction;
+ TDEToolBarPopupAction* m_forwardAction;
bool m_restoring;
TQString m_context;
- KAction *stopAction;
- KAction *reloadAction;
- KAction *duplicateAction;
- KAction *printAction;
- KAction *copyAction;
+ TDEAction *stopAction;
+ TDEAction *reloadAction;
+ TDEAction *duplicateAction;
+ TDEAction *printAction;
+ TDEAction *copyAction;
int m_options;
};
diff --git a/lib/widgets/klistviewaction.cpp b/lib/widgets/klistviewaction.cpp
index 631ad9d1..2d687027 100644
--- a/lib/widgets/klistviewaction.cpp
+++ b/lib/widgets/klistviewaction.cpp
@@ -26,19 +26,19 @@
#include <tdeconfig.h>
#include <kglobal.h>
-KListViewAction::~KListViewAction()
+TDEListViewAction::~TDEListViewAction()
{
TDEConfig *config = TDEGlobal::config();
if (config && m_view->name())
{
- config->setGroup("KListViewAction");
+ config->setGroup("TDEListViewAction");
config->writeEntry(m_view->name(), m_view->width());
}
delete m_view;
}
-KListViewAction::KListViewAction(KComboView *view, const TQString & text, const KShortcut & cut,
- const TQObject * receiver, const char * slot, KActionCollection * parent, const char * name ):
+TDEListViewAction::TDEListViewAction(KComboView *view, const TQString & text, const TDEShortcut & cut,
+ const TQObject * receiver, const char * slot, TDEActionCollection * parent, const char * name ):
KWidgetAction(view, text, cut, receiver, slot, parent, name), m_view(view)
{
m_view->setDuplicatesEnabled(false);
@@ -47,8 +47,8 @@ KListViewAction::KListViewAction(KComboView *view, const TQString & text, const
loadComboWidth();
}
-KListViewAction::KListViewAction( KComboView * view, const TQString & text, const KShortcut & cut,
- const TQObject * receiver, const char * slot, KActionCollection * parent, const char * name, const bool /*dummy*/ ):
+TDEListViewAction::TDEListViewAction( KComboView * view, const TQString & text, const TDEShortcut & cut,
+ const TQObject * receiver, const char * slot, TDEActionCollection * parent, const char * name, const bool /*dummy*/ ):
KWidgetAction(new ResizableCombo(view), text, cut, receiver, slot, parent, name), m_view(view)
{
m_view->setDuplicatesEnabled(false);
@@ -57,29 +57,29 @@ KListViewAction::KListViewAction( KComboView * view, const TQString & text, cons
loadComboWidth();
}
-KComboView * KListViewAction::view( ) const
+KComboView * TDEListViewAction::view( ) const
{
return m_view;
}
-void KListViewAction::setToolTip( const TQString & str )
+void TDEListViewAction::setToolTip( const TQString & str )
{
TQToolTip::remove(m_view);
TQToolTip::add(m_view, str);
}
-void KListViewAction::setWhatsThis( const TQString & str )
+void TDEListViewAction::setWhatsThis( const TQString & str )
{
TQWhatsThis::remove(m_view);
TQWhatsThis::add(m_view, str);
}
-void KListViewAction::loadComboWidth( )
+void TDEListViewAction::loadComboWidth( )
{
TDEConfig *config = TDEGlobal::config();
if (config && m_view->name())
{
- config->setGroup("KListViewAction");
+ config->setGroup("TDEListViewAction");
m_view->setMinimumWidth(config->readNumEntry(m_view->name(), m_view->defaultWidth()));
}
}
diff --git a/lib/widgets/klistviewaction.h b/lib/widgets/klistviewaction.h
index dfe3414a..703f58cf 100644
--- a/lib/widgets/klistviewaction.h
+++ b/lib/widgets/klistviewaction.h
@@ -35,13 +35,13 @@ Widget action with KComboView.
Widget action with KComboView.
Can be used on toolbars. It appears as @ref ResizableCombo.
*/
-class KListViewAction: public KWidgetAction
+class TDEListViewAction: public KWidgetAction
{
public:
- KListViewAction(KComboView *view, const TQString &text, const KShortcut &cut, const TQObject *receiver, const char *slot, KActionCollection *parent, const char *name);
- KListViewAction(KComboView *view, const TQString &text, const KShortcut &cut, const TQObject *receiver, const char *slot, KActionCollection *parent, const char *name, const bool);
+ TDEListViewAction(KComboView *view, const TQString &text, const TDEShortcut &cut, const TQObject *receiver, const char *slot, TDEActionCollection *parent, const char *name);
+ TDEListViewAction(KComboView *view, const TQString &text, const TDEShortcut &cut, const TQObject *receiver, const char *slot, TDEActionCollection *parent, const char *name, const bool);
- ~KListViewAction();
+ ~TDEListViewAction();
KComboView *view() const;
void setToolTip(const TQString & str);
diff --git a/lib/widgets/ksavealldialog.cpp b/lib/widgets/ksavealldialog.cpp
index 72618589..46736be2 100644
--- a/lib/widgets/ksavealldialog.cpp
+++ b/lib/widgets/ksavealldialog.cpp
@@ -57,7 +57,7 @@ KSaveSelectDialog::KSaveSelectDialog( KURL::List const & filelist, KURL::List co
(void)new TQLabel( i18n("The following files have been modified. Save them?"), top );
- _listview = new KListView( top );
+ _listview = new TDEListView( top );
_listview->addColumn( "" );
_listview->header()->hide();
_listview->setResizeMode( TQListView::LastColumn );
@@ -149,7 +149,7 @@ KSaveAllDialog::KSaveAllDialog( const TQStringList& filenames, TQWidget* parent
TQVBox *top = makeVBoxMainWidget();
(void)new TQLabel( i18n("The following files have been modified. Save them?"), top );
- KListBox* lb = new KListBox( top );
+ TDEListBox* lb = new TDEListBox( top );
lb->setMinimumHeight( lb->fontMetrics().height() * 5 );
lb->insertStringList( filenames );
diff --git a/lib/widgets/ksavealldialog.h b/lib/widgets/ksavealldialog.h
index a122b11a..d7b989c5 100644
--- a/lib/widgets/ksavealldialog.h
+++ b/lib/widgets/ksavealldialog.h
@@ -24,7 +24,7 @@
#include <kdialogbase.h>
#include <kurl.h>
-class KListView;
+class TDEListView;
/**
@file ksavealldialog.h
Dialogs to save multiple files.
@@ -51,7 +51,7 @@ private slots:
void cancel();
private:
- KListView * _listview;
+ TDEListView * _listview;
};
diff --git a/lib/widgets/processwidget.cpp b/lib/widgets/processwidget.cpp
index 1f2e1a5e..5bb0bc4e 100644
--- a/lib/widgets/processwidget.cpp
+++ b/lib/widgets/processwidget.cpp
@@ -104,7 +104,7 @@ void ProcessListBoxItem::paint(TQPainter *p)
ProcessWidget::ProcessWidget(TQWidget *parent, const char *name)
- : KListBox(parent, name)
+ : TDEListBox(parent, name)
{
setFocusPolicy(TQ_NoFocus);
diff --git a/lib/widgets/processwidget.h b/lib/widgets/processwidget.h
index b0ad10f7..0ee5b3e6 100644
--- a/lib/widgets/processwidget.h
+++ b/lib/widgets/processwidget.h
@@ -55,7 +55,7 @@ private:
* This class is designed to share code between the
* grep and application output widgets.
*/
-class ProcessWidget : public KListBox
+class ProcessWidget : public TDEListBox
{
Q_OBJECT
diff --git a/lib/widgets/propeditor/pfontbutton.cpp b/lib/widgets/propeditor/pfontbutton.cpp
index 67c86995..fda1322b 100644
--- a/lib/widgets/propeditor/pfontbutton.cpp
+++ b/lib/widgets/propeditor/pfontbutton.cpp
@@ -37,7 +37,7 @@ PFontButton::PFontButton(MultiProperty* property, TQWidget* parent, const char*
:PropertyWidget(property, parent, name)
{
TQHBoxLayout *l = new TQHBoxLayout(this, 0, 0);
- m_edit = new KFontRequester(this);
+ m_edit = new TDEFontRequester(this);
m_edit->setSizePolicy(TQSizePolicy::MinimumExpanding, TQSizePolicy::MinimumExpanding);
#ifndef PURE_QT
m_edit->button()->setText(i18n("..."));
diff --git a/lib/widgets/propeditor/pfontbutton.h b/lib/widgets/propeditor/pfontbutton.h
index 761cb003..3f7d54c6 100644
--- a/lib/widgets/propeditor/pfontbutton.h
+++ b/lib/widgets/propeditor/pfontbutton.h
@@ -22,7 +22,7 @@
#include "propertywidget.h"
-class KFontRequester;
+class TDEFontRequester;
namespace PropertyLib{
@@ -44,7 +44,7 @@ protected slots:
void updateProperty(const TQFont& font);
private:
- KFontRequester *m_edit;
+ TDEFontRequester *m_edit;
};
diff --git a/lib/widgets/propeditor/pfontcombo.h b/lib/widgets/propeditor/pfontcombo.h
index f3ede408..e1a90b69 100644
--- a/lib/widgets/propeditor/pfontcombo.h
+++ b/lib/widgets/propeditor/pfontcombo.h
@@ -23,10 +23,10 @@
#include "propertywidget.h"
#ifdef PURE_QT
-#define KFontCombo TQComboBox
+#define TDEFontCombo TQComboBox
#endif
-class KFontCombo;
+class TDEFontCombo;
namespace PropertyLib{
@@ -49,7 +49,7 @@ private slots:
void updateProperty(const TQString &val);
private:
- KFontCombo *m_edit;
+ TDEFontCombo *m_edit;
};
}
diff --git a/lib/widgets/propeditor/propertyeditor.cpp b/lib/widgets/propeditor/propertyeditor.cpp
index c7eafd8f..1bf3adc9 100644
--- a/lib/widgets/propeditor/propertyeditor.cpp
+++ b/lib/widgets/propeditor/propertyeditor.cpp
@@ -40,16 +40,16 @@
namespace PropertyLib{
-class PropertyItem: public KListViewItem{
+class PropertyItem: public TDEListViewItem{
public:
PropertyItem(PropertyEditor *parent, MultiProperty *property)
- :KListViewItem(parent, property->description()), m_editor(parent), m_property(property),
+ :TDEListViewItem(parent, property->description()), m_editor(parent), m_property(property),
m_changed(false)
{
}
- PropertyItem(PropertyEditor *editor, KListViewItem *parent, MultiProperty *property)
- :KListViewItem(parent, property->description()), m_editor(editor),
+ PropertyItem(PropertyEditor *editor, TDEListViewItem *parent, MultiProperty *property)
+ :TDEListViewItem(parent, property->description()), m_editor(editor),
m_property(property), m_changed(false)
{
}
@@ -97,12 +97,12 @@ public:
m_editor->machine(m_property)->propertyEditor->drawViewer(p, icg, r, valueToDraw);
return;
}
- KListViewItem::paintCell(p, cg, column, width, align);
+ TDEListViewItem::paintCell(p, cg, column, width, align);
}
virtual void setup()
{
- KListViewItem::setup();
+ TDEListViewItem::setup();
setHeight(static_cast<int>(height()*1.5));
}
@@ -118,15 +118,15 @@ private:
};
-class PropertyGroupItem: public KListViewItem{
+class PropertyGroupItem: public TDEListViewItem{
public:
- PropertyGroupItem(KListView *parent, const TQString &name)
- :KListViewItem(parent, name)
+ PropertyGroupItem(TDEListView *parent, const TQString &name)
+ :TDEListViewItem(parent, name)
{
init();
}
- PropertyGroupItem(KListViewItem *parent, const TQString &name)
- :KListViewItem(parent, name)
+ PropertyGroupItem(TDEListViewItem *parent, const TQString &name)
+ :TDEListViewItem(parent, name)
{
init();
}
@@ -141,11 +141,11 @@ public:
p->setBrush(cg.highlight());
p->setPen(cg.highlightedText());
}
- KListViewItem::paintCell(p, cg, column, width, align);
+ TDEListViewItem::paintCell(p, cg, column, width, align);
}
virtual void setup()
{
- KListViewItem::setup();
+ TDEListViewItem::setup();
setHeight(static_cast<int>(height()*1.4));
}
@@ -156,16 +156,16 @@ private:
}
};
-class SeparatorItem: public KListViewItem{
+class SeparatorItem: public TDEListViewItem{
public:
- SeparatorItem(KListView *parent)
- :KListViewItem(parent)
+ SeparatorItem(TDEListView *parent)
+ :TDEListViewItem(parent)
{
setSelectable(false);
}
};
PropertyEditor::PropertyEditor(TQWidget *parent, const char *name)
- :KListView(parent, name)
+ :TDEListView(parent, name)
{
setSorting(-1);
diff --git a/lib/widgets/propeditor/propertyeditor.h b/lib/widgets/propeditor/propertyeditor.h
index 7cfa8521..3e683a58 100644
--- a/lib/widgets/propeditor/propertyeditor.h
+++ b/lib/widgets/propeditor/propertyeditor.h
@@ -24,8 +24,8 @@
#include <klistview.h>
#else
#include <tqlistview.h>
-#define KListView TQListView
-#define KListViewItem TQListViewItem
+#define TDEListView TQListView
+#define TDEListViewItem TQListViewItem
#endif
#include "propertylist.h"
@@ -55,7 +55,7 @@ creation of property widgets from the machine factory.
@see Machine
@see PropertyMachineFactory
*/
-class PropertyEditor: public KListView{
+class PropertyEditor: public TDEListView{
Q_OBJECT
public:
diff --git a/lib/widgets/fancylistviewitem.h b/lib/widgets/fancylistviewitem.h
index 49dc5600..24b17d0a 100644
--- a/lib/widgets/fancylistviewitem.h
+++ b/lib/widgets/fancylistviewitem.h
@@ -119,16 +119,16 @@ class TextPaintItem {
};
///does not support multiple column, a "column" represents a part of the real first column
-///KListViewItem is only needed for the background-color
+///TDEListViewItem is only needed for the background-color
-class FancyListViewItem : public KListViewItem
+class FancyListViewItem : public TDEListViewItem
{
public:
- FancyListViewItem(TextPaintStyleStore& styles, TQListView *parent, const TQString &label1, const TQString &label2="") : KListViewItem(parent, label1, label2), m_styles(styles) {
+ FancyListViewItem(TextPaintStyleStore& styles, TQListView *parent, const TQString &label1, const TQString &label2="") : TDEListViewItem(parent, label1, label2), m_styles(styles) {
init(label1, label2);
}
- FancyListViewItem(TextPaintStyleStore& styles, TQListViewItem *parent, const TQString &label1, const TQString &label2="") : KListViewItem(parent, label1, label2), m_styles(styles) {
+ FancyListViewItem(TextPaintStyleStore& styles, TQListViewItem *parent, const TQString &label1, const TQString &label2="") : TDEListViewItem(parent, label1, label2), m_styles(styles) {
init(label1, label2);
}
diff --git a/lib/widgets/propeditor/pfontcombo.cpp b/lib/widgets/propeditor/pfontcombo.cpp
index 8b0ee7a7..0675a6e0 100644
--- a/lib/widgets/propeditor/pfontcombo.cpp
+++ b/lib/widgets/propeditor/pfontcombo.cpp
@@ -37,11 +37,11 @@ PFontCombo::PFontCombo(MultiProperty *property, TQWidget *parent, const char *na
:PropertyWidget(property, parent, name)
{
TQHBoxLayout *l = new TQHBoxLayout(this, 0, 0);
- m_edit = new KFontCombo(this);
+ m_edit = new TDEFontCombo(this);
m_edit->setSizePolicy(TQSizePolicy::MinimumExpanding, TQSizePolicy::MinimumExpanding);
l->addWidget(m_edit);
/*adymo: KFontCombo seems to have a bug: when it is not editable, the signals
activated(int) and textChanged(const TQString &) are not emitted*/
#ifdef PURE_QT
TQFontDatabase fonts;
@@ -37,11 +37,11 @@ PFontCombo::PFontCombo(MultiProperty *property, TQWidget *parent, const char *na
m_edit->setSizePolicy(TQSizePolicy::MinimumExpanding, TQSizePolicy::MinimumExpanding);
l->addWidget(m_edit);
- /*adymo: KFontCombo seems to have a bug: when it is not editable, the signals
+ /*adymo: TDEFontCombo seems to have a bug: when it is not editable, the signals
activated(int) and textChanged(const TQString &) are not emitted*/
#ifdef PURE_QT